@@ -7,7 +7,7 @@ import json
 from .api import get
 
 
-def save_json(data: dict, path: Union[Path, str] = None, encoding: str = "utf-8"):
+def save_json(data: Union[dict, list[dict]], path: Union[Path, str] = None, encoding: str = "utf-8"):
     if isinstance(path, str):
         path = Path(path)
     path.parent.mkdir(parents=True, exist_ok=True)
@@ -24,14 +24,14 @@ def load_json(path: Union[Path, str], encoding: str = "utf-8"):
 
 async def load_json_from_url(
     url: str, path: Union[Path, str] = None, force: bool = False
-) -> dict:
+) -> Union[dict, list[dict]]:
     if path and Path(path).exists() and not force:
         return load_json(path=path)
     resp = await get(url)
     try:
         data = resp.json()
     except JSONDecodeError:
-        return {}
+        return []
     if path and not Path(path).exists():
         save_json(data=data, path=path)
     return data
