@@ -1,4 +1,3 @@
-from datetime import datetime
 from pathlib import Path
 from typing import Union
 
@@ -17,13 +16,14 @@ from nonebot.permission import SUPERUSER
 from .alias import find_name
 from .api import get
 from .config import Config
-from .deal import deal_info
+from .deal import deal_info_from_name, deal_info_from_version
 from .deal_json import load_json_from_url, save_json
-from .send import word_send
+from .send import word_send_from_name, word_send_from_version
 
 old_gacha = on_regex(
     r"(?<!\w)(?P<name>[\u4e00-\u9fa5]+)(?<!刷新)(历史卡池|历史up)(?P<len>\d{0,2})(?!.)"
 )
+version_gacha = on_regex(r"(?<!.)(?P<version>\d\.\d)(卡池|up)(?P<upordown>(1|2|3)?)(?!.)")
 refresh = on_regex(
     r"(?<!.)刷新(?P<name>历史卡池|别名)(?!.)",
     permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER,
@@ -43,23 +43,45 @@ async def _(
     regex_dict: dict = RegexDict(),
 ):
     type_name = regex_dict["name"]
-    if config.forward_length <= 0:
+    if config.gshisbanner_forward_length <= 0:
         await old_gacha.finish("请不要将合并转发长度设为小于等于0的数字")
     # regex_dict["len"]：表示合并转发的长度,由用户输入获取，为获取到则为默认值
-    length = int(regex_dict["len"]) if regex_dict["len"] else config.forward_length
+    length = (
+        int(regex_dict["len"])
+        if regex_dict["len"]
+        else config.gshisbanner_forward_length
+    )
     # 获取角色真实名字
     real_name, is_type = find_name(type_name)
     if real_name is None or is_type not in ["角色", "武器"]:
         await old_gacha.finish("该角色/武器不存在或是从未up过")
     # 获取up信息
-    info = await deal_info(real_name, "cha" if is_type == "角色" else "wep")
-    end_time = datetime.strptime(info[0]["end"], "%Y-%m-%d %H:%M:%S").date()
-    end_t = (datetime.now().date() - end_time).days
-    delta_time = f"最近一次up距离现在已有{end_t}天" if end_t > 0 else f"当前正在up中,距离结束还有约{-end_t}天"
-    await word_send(bot, event, real_name, delta_time, info, length)
+    info = await deal_info_from_name(real_name, "cha" if is_type == "角色" else "wep")
+    await word_send_from_name(bot, event, real_name, info, length)
     await old_gacha.finish()
 
 
+@version_gacha.handle()
+async def _(bot: Bot, event: MessageEvent, regex_dict: dict = RegexDict()):
+    special_version = ["1.3"]  # 特殊版本
+    # 判断是否为三卡池的版本
+    if regex_dict["version"] not in special_version and regex_dict["upordown"] == "3":
+        await version_gacha.finish()
+    # 获取版本信息
+    real_version = (
+        f"{regex_dict['version']}.{regex_dict['upordown']}"
+        if regex_dict["upordown"]
+        else regex_dict["version"]
+    )
+    # 根据版本获取up信息
+    info = await deal_info_from_version(
+        real_version, False if regex_dict["upordown"] else True
+    )
+    if info is not None:
+        await word_send_from_version(bot, event, real_version, info)
+    await version_gacha.finish()
+
+
 @refresh.handle()
 async def _(
     event: MessageEvent,
